@@ -1,17 +1,18 @@
+from __future__ import annotations
+
 import logging
 import os
 import re
 import subprocess
 from platform import system
 from shutil import which
-from typing import Dict, Iterator, List, Union
+from typing import Iterator
 
 from ffmpeg_progress_yield import FfmpegProgress
 
 from ._errors import FFmpegNormalizeError
-from ._logger import setup_custom_logger
 
-logger = setup_custom_logger("ffmpeg_normalize")
+_logger = logging.getLogger(__name__)
 
 NUL = "NUL" if system() in ("Windows", "cli") else "/dev/null"
 DUR_REGEX = re.compile(
@@ -19,53 +20,20 @@ DUR_REGEX = re.compile(
 )
 
 
-def to_ms(s: Union[str, None] = None, decimals: Union[int, None] = None, **kwargs) -> int:
-    """This function converts a string with time format "hh:mm:ss:ms" to milliseconds
-
-    Args:
-        s (str): String with time format "hh:mm:ss:ms", if not provided, the function will use the keyword arguments (optional)
-        decimals (int): Number of decimals to round to (optional)
-
-    Keyword Args:
-        hour: Number of hours (optional)
-        min: Number of minutes (optional)
-        sec: Number of seconds (optional)
-        ms: Number of milliseconds (optional)
-
-    Returns:
-        int: Integer with the number of milliseconds
-    """
-    if s:
-        hour = int(s[0:2])
-        minute = int(s[3:5])
-        sec = int(s[6:8])
-        ms = int(s[10:11])
-    else:
-        hour = int(kwargs.get("hour", 0))
-        minute = int(kwargs.get("min", 0))
-        sec = int(kwargs.get("sec", 0))
-        ms = int(kwargs.get("ms", 0))
-
-    result = (hour * 60 * 60 * 1000) + (minute * 60 * 1000) + (sec * 1000) + ms
-    if decimals and isinstance(decimals, int):
-        return round(result, decimals)
-    return result
-
-
 class CommandRunner:
     """
     Wrapper for running ffmpeg commands
     """
-    def __init__(self, cmd: List[str], dry: bool = False):
+
+    def __init__(self, dry: bool = False):
         """Create a CommandRunner object
 
         Args:
             cmd: Command to run as a list of strings
-            dry (bool, optional): Dry run mode. Defaults to False.
+            dry: Dry run mode. Defaults to False.
         """
-        self.cmd = cmd
         self.dry = dry
-        self.output: Union[str, None] = None
+        self.output: str | None = None
 
     @staticmethod
     def prune_ffmpeg_progress_from_output(output: str) -> str:
@@ -99,8 +67,7 @@ class CommandRunner:
             ]
         )
 
-
-    def run_ffmpeg_command(self) -> Iterator[int]:
+    def run_ffmpeg_command(self, cmd: list[str]) -> Iterator[int]:
         """
         Run an ffmpeg command
 
@@ -108,50 +75,51 @@ class CommandRunner:
             int: Progress percentage
         """
         # wrapper for 'ffmpeg-progress-yield'
-        logger.debug(f"Running command: {self.cmd}")
-        ff = FfmpegProgress(self.cmd, dry_run=self.dry)
+        _logger.debug(f"Running command: {cmd}")
+        ff = FfmpegProgress(cmd, dry_run=self.dry)
         yield from ff.run_command_with_progress()
 
         self.output = ff.stderr
 
-        if logger.getEffectiveLevel() == logging.DEBUG and self.output is not None:
-            logger.debug(
+        if _logger.getEffectiveLevel() == logging.DEBUG and self.output is not None:
+            _logger.debug(
                 f"ffmpeg output: {CommandRunner.prune_ffmpeg_progress_from_output(self.output)}"
             )
 
-
-    def run_command(self) -> None:
+    def run_command(self, cmd: list[str]) -> CommandRunner:
         """
-        Run the actual command (not ffmpeg)
+        Run a command with subprocess
+
+        Returns:
+            CommandRunner: itself
 
         Raises:
             RuntimeError: If command returns non-zero exit code
         """
-        logger.debug(f"Running command: {self.cmd}")
+        _logger.debug(f"Running command: {cmd}")
 
         if self.dry:
-            logger.debug("Dry mode specified, not actually running command")
-            return
+            _logger.debug("Dry mode specified, not actually running command")
+            return self
 
         p = subprocess.Popen(
-            self.cmd,
+            cmd,
             stdin=subprocess.PIPE,  # Apply stdin isolation by creating separate pipe.
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             universal_newlines=False,
         )
 
-        # simple running of command
         stdout_bytes, stderr_bytes = p.communicate()
 
         stdout = stdout_bytes.decode("utf8", errors="replace")
         stderr = stderr_bytes.decode("utf8", errors="replace")
 
-        if p.returncode == 0:
-            self.output = stdout + stderr
-        else:
-            raise RuntimeError(f"Error running command {self.cmd}: {stderr}")
+        if p.returncode != 0:
+            raise RuntimeError(f"Error running command {cmd}: {stderr}")
 
+        self.output = stdout + stderr
+        return self
 
     def get_output(self) -> str:
         if self.output is None:
@@ -159,12 +127,12 @@ class CommandRunner:
         return self.output
 
 
-def dict_to_filter_opts(opts: Dict[str, str]) -> str:
+def dict_to_filter_opts(opts: dict[str, object]) -> str:
     """
     Convert a dictionary to a ffmpeg filter option string
 
     Args:
-        opts (Dict[str, str]): Dictionary of options
+        opts (dict[str, object]): Dictionary of options
 
     Returns:
         str: Filter option string
@@ -215,12 +183,10 @@ def ffmpeg_has_loudnorm() -> bool:
     Returns:
         bool: True if loudnorm is supported, False otherwise
     """
-    cmd_runner = CommandRunner([get_ffmpeg_exe(), "-filters"])
-    cmd_runner.run_command()
-
-    supports_loudnorm = "loudnorm" in cmd_runner.get_output()
+    output = CommandRunner().run_command([get_ffmpeg_exe(), "-filters"]).get_output()
+    supports_loudnorm = "loudnorm" in output
     if not supports_loudnorm:
-        logger.error(
+        _logger.error(
             "Your ffmpeg does not support the 'loudnorm' filter. "
             "Please make sure you are running ffmpeg v4.2 or above."
         )
